<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Devices.Adc

Windows Runtime (WinRT) APIs for for the `Windows.Devices.Adc` namespace.

This package provides the `winrt.windows.devices.adc` module.
